Leader

Struct Leader 

pub struct Leader {
    pub record_length: u16,
    pub status: Status,
    pub record_type: RecordType,
    pub bibliographical_level: BibliographicalLevel,
    pub control_type: ControlType,
    pub coding_scheme: CodingScheme,
    pub data_base_address: u16,
    pub encoding_level: EncodingLevel,
    pub descriptive_cataloging_form: CatalogingForm,
    pub multipart_resource_record_level: MultipartResourceRecordLevel,
}
The leader is MARC’s equivalent of a header. It contains internal bookkeeping info about the record as well as some information of interest to the applications reading it.

Fields

record_length: u16

Length in bytes of the record

status: Status

The status of the information, e.g. whether the sender signals it is a new entry or a correction

record_type: RecordType

The type of content described by the record, will alter which fields should be provided.

bibliographical_level: BibliographicalLevel

Mostly used to tell whether this is for a single item or a collection

control_type: ControlTypecoding_scheme: CodingScheme

Tells which encoding was used for the text of the variable data fields.

data_base_address: u16

Byte index of the variable field data, after the leader and the dictionary

encoding_level: EncodingLevel

Represents something like the quality of the data about the entry

descriptive_cataloging_form: CatalogingFormmultipart_resource_record_level: MultipartResourceRecordLevel