Record

Struct Record 

pub struct Record {
    pub leader: Leader,
    pub fields: Vec<Field>,
}
A MARC record describes a content or piece of content using a series of fields. Fields are identified by a three-digit ASCII code (e.g. 001) and contain either control or field data. Control fields are identified by being in the 000-099 range while data fields are all the others. Control fields contain a single piece of information

Fields

leader: Leader

The leader is MARC’s way of naming the header info

fields: Vec<Field>

The actual control and data fields