ControlField

Struct ControlField 

pub struct ControlField {
    pub tag: FieldTag,
    pub data: String,
}
The first fields of a MARC record represent control data. Unlike the variable data fields, they are simple blob of ASCII content, although some of them are encoded with a specific scheme (for example, some of them are pipe-separated values)

Fields

tag: FieldTagdata: String