pub struct DataField {
pub tag: FieldTag,
pub indicator: Vec<char>,
pub subfields: Vec<Subfield>,
}Expand description
One of the variable data fields representing the bulk of the information found in the MARC record. The tag along with the indicators (of which there are typically 2) help figure out the specific meaning of the data found within the subfields or blocks of content.
Fields
tag: FieldTagindicator: Vec<char>subfields: Vec<Subfield>Trait Implementations
impl Eq for DataField
impl StructuralPartialEq for DataField